@@ -3,12 +3,10 @@ Test GETting a tiddler revision list.
 """
 
 
-from wsgi_intercept import httplib2_intercept
-import wsgi_intercept
 import httplib2
 import simplejson
 
-from fixtures import muchdata, reset_textstore, _teststore
+from fixtures import muchdata, reset_textstore, _teststore, initialize_app
 
 
 from tiddlyweb.util import sha
@@ -30,15 +28,7 @@ Hello, I'm John Smith \xbb and I have something to sell.
 """
 
 def setup_module(module):
-    from tiddlyweb.web import serve
-    # we have to have a function that returns the callable,
-    # Selector just _is_ the callable
-    def app_fn():
-        return serve.load_app()
-    #wsgi_intercept.debuglevel = 1
-    httplib2_intercept.install()
-    wsgi_intercept.add_wsgi_intercept('our_test_domain', 8001, app_fn)
-
+    initialize_app()
     reset_textstore()
     module.store = _teststore()
     muchdata(module.store)
